@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20210430';
+our $VERSION = '0.20210531';
 
-# Table last modified: 2021-04-30
+# Table last modified: 2021-05-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -63,7 +63,7 @@ our %ZIP_TABLE = (
     '057' => '(?:85(?:11|58))',
     '058' => '(?:(?:0292|8501))',
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
-    '060' => '(?:8(?:6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|2[0-57-9]|6[16-8]|4[0-46-9]|3[0-24-9])|5(?:[238]\d|4[1-9]|6[0135-9]|1[1-35-9]|7[02-9]|0[1-68]|5[0-46-9])|7(?:11|67|76|2[015]|9[5-7]|0[35-7])|406))',
+    '060' => '(?:8(?:6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[1-57-9]|4[0-46-9]|3[0-24-9])|5(?:[238]\d|4[1-9]|6[0135-9]|1[1-35-9]|7[02-9]|0[1-68]|5[0-46-9])|7(?:11|67|76|2[015]|9[15-7]|0[35-7])|406))',
     '061' => '(?:(?:1(?:49[236-8]|39[2356]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
     '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68]|5[56])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:5(?:22|0[17]|5[58]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
@@ -107,7 +107,7 @@ our %ZIP_TABLE = (
     '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-35689])|3(?:6[2356]|4[5-7]|0[12578]|7[0-258]|8[1358]|5[0-689]|2[1-8]|3[013568]|1[013-7])|6(?:1[0-35-79]|8[28]|6[2578]|3[01346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[04-68]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-79])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|2[0146]|4[05]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:0[2359]|4[19]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|7[0237]|5[0367])|0(?:30|2[24-6]|7[78]|8[0-358]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|7[03568]|4[013578])|3(?:7[03]|1[1378]|5[0-2458]|2[1348]|0[136-8]|8[0348]|4[15-7]|6[036]|3[01357-9])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[067]|6[068]|8[0469]|3[1269])|0[01]1)|6060))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|5[158]|1[014-8]|8[1389]|4[25]|3[0-589]|7[014-9])|3(?:7[027-9]|1[0-3579]|2[458]|8[013689]|6[05]|5[0167]|3[02358]|4[0-5]|0[1-79])|5(?:72|1[028]|3[035689]|8[01458]|4[3-8]|5[014-689]|2[0136-8]|6[06-8]|0[1256])|4(?:70|3[013589]|4[03489]|0[124-8]|8[168]|2[0-4679]|5[0156]|6[08]|1[05689])|2(?:22|40|1[0-258]|7[17]|3[38]|0[568]|8[0-589]|5[0-24-8]|6[026])|6(?:14|5[06]|6[0158]|8[05]|7[08])|0(?:55|77|0[1-47]|1[01]))|6241))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|5[158]|1[014-8]|8[1389]|4[25]|3[0-589]|7[014-9])|3(?:7[027-9]|1[0-3579]|2[458]|8[013689]|6[05]|5[0167]|3[02358]|4[0-5]|0[1-79])|4(?:70|3[013589]|0[124-8]|8[168]|4[02-489]|2[0-4679]|5[0156]|6[08]|1[05689])|5(?:72|1[028]|3[035689]|8[01458]|4[3-8]|5[014-689]|2[0136-8]|6[06-8]|0[1256])|2(?:22|40|1[0-258]|7[17]|3[38]|0[568]|8[0-589]|5[0-24-8]|6[026])|6(?:14|5[06]|6[0158]|8[05]|7[08])|0(?:55|77|0[1-47]|1[01]))|6241))',
     '105' => '(?:(?:8(?:4(?:6[014589]|5[1-36-8]|7[0-357]|3[1-7]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9]|8[2-68])|5(?:6[03578]|5[013-8]|1[0-25-8]|8[0-589]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:3[04]|6[0568]|2[0136]|8[015689]|5[468]|1[013-57]|4[024]|7[06-8]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:20|39|55|0[1258]|7[07]|8[58]|1[01])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|7[136-8]|3[17]|1[458]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|0[18]|2[0256]|3[069])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|5(?:32|81|1[14]|0[2578]|7[27]|2[0178]|6[037]|5[0268]|4[56])|6(?:50|8[06]|0[14]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|3(?:55|60|4[0289]|7[013]|2[0346]|8[048]|3[026])|0(?:[16]0|77|0[16])))',
@@ -143,7 +143,7 @@ our %ZIP_TABLE = (
     '150' => '(?:8(?:5(?:45|6[37]|2[256]|7[57]|8[578]|1[0-24-7]|5[1-5]|0[2357-9]|3[038])|3(?:19|4[03]|7[37]|3[0368]|8[45]|2[24-8]|0[1367]|5[05]|6[036])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:3\d|0[2-79]|5[024589]|1[016-9]|6[1-35-9]|[24][0-57-9]|9[0-2]|7[0-46-8]|8[02-7])|6(?:5[1-3]|7[1-7]|0[01])|40[14]|070))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
-    '153' => '(?:8(?:5(?:7[1378]|2[0-356]|6[057]|5[0-68]|4[0135]|8[0-25-79]|0[1-68]|3[0169]|1[02568])|6(?:[14]0|01|8[78]|2[02]|6[025689]|5[02-57]|3[013568]|7[017])|9(?:1[134]|0[246]|2[357]|3[034679])))',
+    '153' => '(?:8(?:5(?:7[1378]|2[0-356]|6[057]|5[0-68]|4[0135]|8[0-25-79]|0[1-68]|3[0169]|1[02568])|6(?:01|40|1[06]|8[78]|2[02]|6[025689]|5[02-57]|3[013568]|7[017])|9(?:1[134]|0[246]|2[357]|3[034679])))',
     '154' => '(?:8(?:5(?:8[0-245]|4[3-5]|3[02369]|6[05-8]|2[0135]|0[3-69]|5[1-5]|1[0156]|7[017])|7(?:03|32)))',
     '155' => '(?:86(?:10|26|33|55|6[38]))',
     '156' => '(?:8(?:5(?:33|55|88|0[246]|2[02]|1[01])|666))',
@@ -196,7 +196,7 @@ our %ZIP_TABLE = (
     '207' => '(?:85(?:[18]5|01))',
     '208' => '(?:85(?:[58]5|0[1-3]))',
     '210' => '(?:(?:8(?:5(?:0[246]|6[0259]|2[13]|8[356]|3[178]|4[013-578]|7[067]|1[12]|5[127-9])|6(?:66|0[24]|8[016])|79[3-8])|9(?:5(?:11|26|55|67|82|3[03]|0[17])|650)))',
-    '211' => '(?:8(?:5(?:[34]0|66|2[02]|7[07]|8[58]|5[05]|1[01]|0[125])|6(?:01|66|75|1[19])))',
+    '211' => '(?:8(?:5(?:40|66|3[03]|2[02]|7[07]|8[58]|5[05]|1[01]|0[125])|6(?:01|66|75|1[19])))',
     '212' => '(?:8(?:5(?:30|6[0467]|2[05]|5[147]|7[0267]|0[2589]|8[1-59]|1[01])|60[23]))',
     '213' => '(?:85(?:66|2[0-35]|0[2357]|5[01389]|8[016-9]|1[125-7]|3[35]|7[0367]))',
     '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
@@ -272,7 +272,7 @@ our %ZIP_TABLE = (
     '296' => '(?:(?:860[12]|0197))',
     '297' => '(?:(?:8(?:5(?:[01]1|33|67|88|5[058])|6(?:11|22|66))|0(?:19[2-8]|29[28])))',
     '298' => '(?:(?:029[25-7]|8501))',
-    '299' => '(?:(?:4(?:39[24-6]|[126]92|49[23])|0(?:29[235-8]|19[2458])|2(?:[1245]92|79[25])|5(?:29[25]|192)|119[245]))',
+    '299' => '(?:(?:4(?:39[24-7]|[126]92|49[23])|0(?:29[235-8]|19[2458])|2(?:[1245]92|79[25])|5(?:29[25]|192)|119[245]))',
     '300' => '(?:(?:0(?:3(?:88|9[2-8])|19[235]|49[26]|59[35]|[67]92)|2(?:6(?:86|9[258])|49[2-578]|79[2357]|395|593)|1(?:29[24-6]|19[235]|[3-5]92|696)|8(?:5(?:50|67|88)|6(?:01|19|86))|4(?:29[35]|193|495|598)|3(?:59[258]|29[45])))',
     '301' => '(?:8(?:6(?:0[12]|1[01])|5(?:55|0[15])))',
     '302' => '(?:(?:85(?:0[12]|8[56])|0198))',
@@ -292,7 +292,7 @@ our %ZIP_TABLE = (
     '316' => '(?:85(?:11|33|0[12]))',
     '317' => '(?:8(?:5(?:[58]5|11)|60[12]))',
     '318' => '(?:85[01]1)',
-    '319' => '(?:(?:1(?:1(?:9[24-7]|8[48])|29[235]|59[23]|393)|0(?:39[3-57]|29[245]|19[28])|2[16]92|3595))',
+    '319' => '(?:(?:1(?:1(?:8[248]|9[24-7])|29[235]|59[23]|393)|0(?:39[3-57]|29[245]|19[28])|2[16]92|3595))',
     '320' => '(?:8(?:5(?:5[015]|3[0-38]|0[1-35-8]|8[058]|4[013]|7[07]|6[046]|2[1-358]|1[0-2457])|6(?:01|20|55|68|1[018]|8[068])))',
     '321' => '(?:(?:3(?:29[235-8]|39[258]|49[378]|59[578])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|4(?:39[23568]|29[235])|1(?:29[23]|49[23])|85(?:[58]5|0[25])))',
     '322' => '(?:(?:8(?:5(?:11|0[1-3]|8[58]|5[05])|6(?:66|88|0[13]))|0(?:393|692)))',
@@ -304,7 +304,7 @@ our %ZIP_TABLE = (
     '328' => '(?:(?:8(?:5(?:33|0[1-4]|5[0568]|8[5-8])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:0(?:59[568]|49[28]|69[26]|195)|1(?:19[3468]|39[235]|292|493)|2(?:19[23]|79[23]|99[23]|292)|4(?:49[238]|392)|3292))',
     '330' => '(?:(?:9(?:5(?:25|90|5[013589]|4[03-58]|8[0-36-8]|6[4-6]|3[156]|7[57]|1[12]|0[1-37-9])|6(?:[69]6|11|30|88|0[18]|2[126])|7(?:3[19]|2[07]|9[2367]|1[0357])|3(?:30|77|0[13]|1[01])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:47|6[24-6]|5[0-3]|0[13568]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|0[13]|8[68])|7(?:10|77))))',
-    '331' => '(?:(?:8(?:5(?:[24]0|01|77|1[13]|8[05-8]|5[02]|6[07]|3[237])|6(?:25|33|58|8[6-8])|701)|9(?:5(?:[1-35]0|77)|624)))',
+    '331' => '(?:(?:8(?:5(?:[24]0|01|77|1[13]|8[05-8]|5[02]|6[07]|3[237])|6(?:25|33|58|8[6-8])|701)|95(?:[1-35]0|77)))',
     '332' => '(?:8(?:5(?:21|33|48|77|85|0[1-3]|5[568]|1[12])|6(?:[68]6|01|54)))',
     '333' => '(?:86[01]1)',
     '334' => '(?:8501)',
@@ -338,7 +338,7 @@ our %ZIP_TABLE = (
     '362' => '(?:8(?:5(?:[67]7|42|0[148]|3[19]|2[013]|8[58]|5[035]|1[017])|688))',
     '363' => '(?:8(?:5(?:10|0[159]|5[58])|601))',
     '364' => '(?:8(?:5(?:[01]1|[58]5)|633))',
-    '365' => '(?:8(?:5(?:[58]5|1[24]|0[1-3568])|60[13]))',
+    '365' => '(?:8(?:5(?:85|1[24]|0[1-3568])|60[13]))',
     '366' => '(?:85(?:67|81|1[015]|0[12]))',
     '367' => '(?:(?:0(?:29[26-8]|19[248])|8(?:501|686)))',
     '368' => '(?:(?:8(?:6(?:66|8[06])|50[125])|0(?:19[235]|292)))',
@@ -349,7 +349,7 @@ our %ZIP_TABLE = (
     '373' => '(?:8(?:5(?:21|78|1[0-35]|0[1589]|8[58]|5[0157]|3[01]|6[017])|6(?:01|22|6[068]|8[68]|1[01])|718))',
     '374' => '(?:(?:8(?:5(?:01|20|33|55|77|88|1[0-28])|6(?:11|22|40|86|0[18]))|019[23]))',
     '375' => '(?:8(?:50[1-6]|60[1-4]))',
-    '376' => '(?:(?:8(?:5(?:31|85|0[1-3]|1[056]|2[38]|5[58])|6(?:86|6[68]))|0(?:19[2-4]|39[27])))',
+    '376' => '(?:(?:8(?:5(?:31|85|1[056]|2[38]|5[58]|0[12])|6(?:86|6[68]))|0(?:19[2-4]|39[27])))',
     '377' => '(?:(?:0(?:8(?:8[23]|9[2-46-8])|2(?:80|9[2-4])|19[235]|39[25]|49[24]|792)|8(?:5(?:[67]7|20|33|55|1[013]|0[1-38]|8[58])|616)|1(?:79[2-7]|39[235]|59[3-5]|69[235])))',
     '378' => '(?:(?:0498|8501))',
     '379' => '(?:(?:2(?:1(?:8[014-7]|9[2-578])|39[258]|29[28])|1(?:29[78]|[16]92|393|498)|0(?:19[235-7]|292)))',
@@ -373,7 +373,7 @@ our %ZIP_TABLE = (
     '397' => '(?:(?:8(?:5(?:67|71|8[58]|5[05])|60[29])|0[23]92))',
     '398' => '(?:8(?:6(?:86|0[12])|501))',
     '399' => '(?:(?:8(?:7(?:44|60|0[127]|2[0-258]|5[0145]|1[0-2]|3[0389])|2(?:9[2357]|8[1-3568])|3(?:86|92)|69[56]|192)|4(?:5(?:6[4-8]|8[13-9]|9[2-578]|7[0-3568])|69[235-7]|39[2-5]|19[25]|498)|0(?:7(?:9[67]|8[1256])|49[235-8]|29[235])|3(?:19[23]|295|797|892)|1(?:392|511|689|895)|9(?:192|393|494)|719[24]|6493))',
-    '400' => '(?:(?:8(?:5(?:8[568]|1[0-25]|4[03-5]|7[01578]|5[025689]|0[125689]|2[15]|6[56]|3[1356])|6(?:01|10|33|66)|794)|0(?:2(?:80|9[238])|19[2-6]|49[2358]|39[358]|59[238]|69[235])|159[2-478]))',
+    '400' => '(?:(?:8(?:5(?:2[015]|8[568]|1[0-25]|4[03-5]|7[01578]|5[025689]|0[125689]|6[56]|3[1356])|6(?:01|10|33|66)|794)|0(?:2(?:80|9[238])|19[2-6]|49[2358]|39[358]|59[238]|69[235])|159[2-478]))',
     '401' => '(?:(?:0(?:3(?:80|9[5-8])|59[257]|292)|8[56]01))',
     '402' => '(?:85(?:01|55|80))',
     '403' => '(?:8(?:5(?:22|55)|601))',
@@ -395,7 +395,7 @@ our %ZIP_TABLE = (
     '419' => '(?:0(?:19[23]|29[35]|392))',
     '420' => '(?:8(?:6(?:6[06]|2[02-48]|4[14]|0[1-468]|8[0158]|7[07]|3[03679]|5[05]|1[0-268])|5(?:70|1[0-257]|0[1-357-9]|8[0158]|6[07]|5[0578]|2[0-3578]|3[06-8])|7(?:47|0[3469]|[12][02]|3[389]|6[01])))',
     '421' => '(?:(?:0(?:1(?:88|9[23578])|39[2-7]|59[23568]|49[2356]|29[238])|3(?:29[25-7]|392)|1(?:29[58]|392)))',
-    '422' => '(?:8(?:5(?:45|50|8[015]|[26]\d|0[24-79]|7[0-68]|3[01]|1[0-24-9])|6(?:5[04]|3[03]|7[07]|8[068]|6[68]|1[059]|2[0-28])|7(?:66|87)))',
+    '422' => '(?:8(?:5(?:45|50|8[015]|[26]\d|0[24-79]|7[013-68]|3[01]|1[0-24-9])|6(?:5[04]|3[03]|7[07]|8[068]|6[68]|1[059]|2[0-28])|7(?:66|87)))',
     '424' => '(?:(?:8(?:6(?:48|50|0[1-3]|7[78]|3[1367]|[68][68]|1[01]|2[024])|7(?:82|3[04]|2[0147]|5[0-25]|6[07]|0[18]|1[579])|5(?:66|0[23]|5[058]|1[01]))|0(?:19[23]|292)))',
     '425' => '(?:8(?:5(?:[58]5|[67]0|11|22|33|0[1-358])|6(?:11|8[06])|7(?:11|0[18])))',
     '426' => '(?:(?:8(?:6(?:01|7[07]|3[1-38]|1[27]|4[026]|6[2368])|5(?:39|43|66|1[015]|0[13]|7[057])|7(?:11|22))|0292))',
@@ -419,7 +419,7 @@ our %ZIP_TABLE = (
     '445' => '(?:8(?:5(?:[58]5|1[01]|0[1-35])|60[12]))',
     '446' => '(?:8(?:5(?:40|1[124578]|5[058]|3[35]|0[1-8]|8[58]|2[0-6])|6(?:35|41|86|0[12])))',
     '447' => '(?:8(?:5(?:0[1-35-7]|1[0-2])|6(?:[18]0|0[1358])))',
-    '448' => '(?:8(?:6(?:10|22|0[1259]|5[0-35-7]|6[0156]|8[68]|7[017])|5(?:50|0[156]|2[35]|3[13-5]|4[023])|731))',
+    '448' => '(?:8(?:6(?:10|22|0[1259]|5[0-35-7]|6[0156]|8[68]|7[017])|5(?:11|50|0[156]|2[35]|3[13-5]|4[023])|731))',
     '449' => '(?:029[23])',
     '450' => '(?:(?:8(?:5(?:40|85|0[135]|[23][03]|6[17]|7[57]|1[15])|6(?:[05]1|[48]0|2[06]|1[1458])|7(?:11|30|65)|99[35-7])|6(?:(?:13|36)3|660)))',
     '451' => '(?:8(?:5(?:[14]1|2[02]|[56][0158]|0[1-38]|7[0157])|6(?:[15]0|66|88)|701))',
@@ -469,7 +469,7 @@ our %ZIP_TABLE = (
     '496' => '(?:8(?:5(?:[78]5|3[1-57]|0[138]|5[58])|6(?:01|48|86|3[39])|720))',
     '497' => '(?:8(?:5(?:[04][158]|3[138]|2[27]|1[0-2])|601))',
     '498' => '(?:850[1-35])',
-    '500' => '(?:8(?:6(?:[14][0568]|5[057]|7[0-26-8]|2[0-25]|0[1-357]|8[0-25-79]|3[05-9]|6[06-8])|5(?:88|6[0-25-7]|0[1-578]|1[0358]|4[0145]|2[1-5]|3[035]|7[017]|5[024-8])|7(?:65|4[0-38]|1[015-8]|3[0-479]|5[0-5]|0[1-378]|2[0-257-9])))',
+    '500' => '(?:8(?:6(?:[14][0568]|5[057]|7[0-26-8]|2[0-25]|0[1-357]|8[0-25-79]|3[05-9]|6[06-8])|5(?:88|6[0-25-7]|0[1-578]|1[0358]|4[0145]|2[1-5]|3[035]|7[017]|5[024-8])|7(?:65|4[0-38]|2[1257-9]|1[015-8]|3[0-479]|5[0-5]|0[1-378])))',
     '501' => '(?:(?:0(?:49[2-8]|69[2-7]|29[2-6]|59[26]|79[78]|[13]92)|3(?:99[2-48]|29[356]|39[235]|89[2-4]|792)|6(?:1(?:9[2-8]|8[01])|29[235])|1(?:19[2-68]|39[23]|[25]92)|4(?:29[278]|19[23]|59[25])|2(?:[1258]92|69[578])|5(?:[146]92|393)))',
     '502' => '(?:8(?:5(?:[12]1|58|67|85|0[13])|792))',
     '503' => '(?:(?:8(?:5(?:5[02-46-9]|2[0-3]|[01][1-9]|7[01]|6[0-24-9])|60[134])|2(?:39[2-7]|49[2-5]|19[23])|0(?:19[258]|29[25]|[46]95|392)|1(?:39[2-6]|59[235]|696)))',
@@ -866,21 +866,21 @@ our %ZIP_TABLE = (
     '905' => '(?:(?:0(?:59[2-6]|79[2-6]|[24]92|695)|8(?:5(?:01|12|40|85)|6(?:11|68))|1(?:[23]92|495)|2192))',
     '906' => '(?:(?:8(?:5(?:01|50)|601)|0[256]92))',
     '907' => '(?:(?:850[1-3]|1[28]92))',
-    '910' => '(?:(?:8(?:5(?:3[0235-9]|4[0-58]|[28]\d|0[1-47-9]|5[0-57-9]|1[0-79]|6[0-24-8]|7[15689])|6(?:22|30|6[056]|0[136]|5[05]|8[068]|7[08]|1[01])|730)|1(?:19[2-5]|29[2-5]|392)|0(?:29[236-8]|39[23])|(?:23|3[56])92|419[35-8]))',
+    '910' => '(?:(?:8(?:5(?:3[0235-9]|4[0-58]|8\d|0[1-47-9]|5[0-57-9]|1[0-79]|6[0-24-8]|2[0-8]|7[15689])|6(?:22|30|6[056]|0[136]|5[05]|8[068]|7[08]|1[01])|730)|1(?:19[2-5]|29[2-5]|392)|0(?:29[236-8]|39[23])|(?:23|3[56])92|419[35-8]))',
     '911' => '(?:8(?:5(?:[03]1|[14]0|85|5[58])|601))',
     '912' => '(?:(?:8(?:5(?:[58]5|24|40|67)|6[68]6)|0292))',
     '913' => '(?:8(?:5(?:[01]1|33|55|77|8[58])|611))',
     '914' => '(?:(?:8(?:5(?:[14]0|24|67|5[058]|8[05]|0[12])|6(?:09|66|8[68]))|019[258]))',
     '915' => '(?:(?:8(?:5(?:01|55|3[03]|2[04]|8[568]|1[01])|666)|0292|1195))',
     '916' => '(?:(?:8(?:5(?:67|5[058]|8[58]|1[05]|0[1578])|6(?:[468]6|01))|0(?:29[235]|[14]92)|1198))',
-    '917' => '(?:(?:8(?:5(?:[24]4|33|77|6[17]|5[058]|1[12]|0[57]|8[0458])|6(?:01|86))|0(?:29[378]|39[38]|198)))',
+    '917' => '(?:(?:8(?:5(?:[24]4|33|77|6[17]|5[058]|1[12]|0[57]|8[0458])|6(?:01|86))|0(?:29[378]|[13]98)))',
     '918' => '(?:8(?:5(?:4[03]|6[05-8]|1[0158]|7[0578]|2[0235]|3[037]|5[02568]|8[03568]|0[1-3589])|6(?:68|8[168])))',
     '919' => '(?:(?:0(?:59[24578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
     '920' => '(?:(?:8(?:5(?:4[0134]|2[0-25]|3[0135-9]|1[0-35-8]|7[0357]|0[1-57-9]|5[0-8]|[68][035-8])|6(?:8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69]|2[0-3568])|7(?:[67]7|30|9[3-7]|0[17]|2[189]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
     '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|3[0-269]|0[15-8]|2[035-79]|8[0-589]|4[1468]|7[1-79])|6(?:01|16|50|3[079]|2[01])|798))',
     '922' => '(?:(?:8(?:5(?:[37]0|01|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[3-578]|19[23]|49[57]|595)))',
     '923' => '(?:(?:8(?:5(?:6[05-7]|5[0-257]|8[0168]|7[058]|3[013]|2[0158]|0[1-357]|4[14-6]|1[01])|6(?:50|66|2[06]|4[02-46]|0[13569]|1[0156]|8[68]|3[039]))|1(?:29[2-7]|198)|039[238]))',
-    '924' => '(?:8(?:5(?:22|33|44|77|6[06]|8[058]|5[58]|1[01])|68[68]))',
+    '924' => '(?:8(?:5(?:22|33|44|77|6[06]|8[058]|5[58]|1[01])|68[68]|777))',
     '925' => '(?:(?:8(?:5(?:11|30|85|6[67]|0[12568]|5[05]|2[15])|6(?:[12]0|09|88))|0(?:19[38]|392|498|697)))',
     '926' => '(?:(?:8(?:5(?:[013]1|20|66|4[015]|8[568]|5[058])|6(?:[68]6|42|50|1[01]|0[1-359]))|0(?:29[23]|192)))',
     '927' => '(?:(?:0(?:49[235]|29[23]|695)|129[57]|219[23]|8601))',
@@ -903,7 +903,7 @@ our %ZIP_TABLE = (
     '944' => '(?:(?:8(?:5(?:01|88|5[05])|6(?:01|86))|0192))',
     '945' => '(?:(?:8(?:5(?:[01]1|[38]5|40|5[58])|6(?:[01]1|88))|1(?:39[23578]|[15]95)|0(?:19[2-4]|39[57])))',
     '946' => '(?:(?:8(?:513|601)|0292))',
-    '947' => '(?:(?:8(?:5(?:[58]5|0[1-46])|7(?:01|65))|019[238]))',
+    '947' => '(?:(?:8(?:5(?:[58]5|40|0[1-46])|7(?:01|65))|019[238]))',
     '948' => '(?:(?:8(?:50[1-4]|602)|0192))',
     '949' => '(?:(?:7(?:49[24-6]|59[24]|277|392)|3(?:29[2-468]|19[2-4]|494)|6(?:69[256]|[124]92|797)|4(?:19[2-4]|39[278])|2(?:19[2-4]|39[24])|5(?:49[2-4]|292)|039[238]|8492))',
     '950' => '(?:(?:8(?:5(?:6[05-7]|2[02-48]|3[0-3579]|0[1-57]|5[0-35-9]|7[0-25-79]|4[013-8]|8[0-689]|1[0-248])|6(?:7[78]|6[0168]|1[0-29]|5[0145]|0[1-3568]|[48][01]|2[0-69]|3[039])|7(?:0[7-9]|5[01359]|3[0235-8]|2[0-57]|1[015-8]|9[48]|4[0-24-9])|801)|2(?:0(?:8[24-9]|9[235-7])|1(?:8[18]|9[258])|292)|1(?:1(?:9[2-7]|8[1-35-9])|29[2-68]|49[258])|0(?:19[23568]|292)|3(?:19[578]|393)))',
